
'''
	{
		"label": "form proposal keys",
		"fields": {
			"seed": ""
		}
	}
'''

import reelity.instrument.climate as instrument_climate

def perform (fields):
	print ("make card")

	seed = fields ["seed"]


	return;